PayUKYCParamKey class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- bankId → const String
- clientId → const String
- clientTxnId → const String
- consent → const String
- customerMobile → const String
- entityId → const String
- environment → const String
- modeId → const String
- redirectionUrl → const String
- secureCode → const String